@@ -109,8 +109,7 @@ applet_change_size(PanelApplet *applet_widget, int size, NetspeedApplet *applet)
 }
 
 /* Change the background of the applet according to
- * the panel background
- * shamelessly stolen from gweather applet
+ * the panel background.
  */
 static void 
 change_background_cb(PanelApplet *applet_widget, 
@@ -118,28 +117,30 @@ change_background_cb(PanelApplet *applet_widget,
 				GdkColor *color, GdkPixmap *pixmap, 
 				NetspeedApplet *applet)
 {
+	GtkStyle *style;
 	GtkRcStyle *rc_style = gtk_rc_style_new ();
+	gtk_widget_set_style (GTK_WIDGET (applet_widget), NULL);
+	gtk_widget_modify_style (GTK_WIDGET (applet_widget), rc_style);
+	gtk_rc_style_unref (rc_style);
 
 	switch (type)
 	{
 		case PANEL_PIXMAP_BACKGROUND:
-			gtk_widget_modify_style(GTK_WIDGET(applet->applet), rc_style);
+			style = gtk_style_copy (GTK_WIDGET (applet_widget)->style);
+			if(style->bg_pixmap[GTK_STATE_NORMAL])
+				g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
+			style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
+			gtk_widget_set_style (GTK_WIDGET(applet_widget), style);
+			g_object_unref (style);
 			break;
 
 		case PANEL_COLOR_BACKGROUND:
-			gtk_widget_modify_bg(GTK_WIDGET(applet->applet), GTK_STATE_NORMAL, color);
+			gtk_widget_modify_bg(GTK_WIDGET(applet_widget), GTK_STATE_NORMAL, color);
 			break;
 
 		case PANEL_NO_BACKGROUND:
-			gtk_widget_modify_style(GTK_WIDGET(applet->applet), rc_style);
-			break;
-
-		default:
-			gtk_widget_modify_style(GTK_WIDGET(applet->applet), rc_style);
 			break;
 	}
-
-	gtk_rc_style_unref(rc_style);
 }
 
 
@@ -182,6 +183,7 @@ change_icons(NetspeedApplet *applet)
 	{
 		guchar *pixels;
 		in = gdk_pixbuf_new(GDK_COLORSPACE_RGB, TRUE, 8, SUMWIDTH, HEIGHT);
+		out = NULL;
 		pixels = gdk_pixbuf_get_pixels(in);
 		memset(pixels, 0, SUMWIDTH * HEIGHT * COL_SAMPLES);
 	}
@@ -410,7 +412,6 @@ update_applet(NetspeedApplet *applet)
 	double inrate, outrate;
 	char *in, *out, *sum;
 	char *tooltip, *inbytes, *outbytes;
-	guint64 rx, tx;
 	int i;
 	DevInfo oldinfo;
 	
@@ -574,34 +575,32 @@ help_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 static void
 about_cb(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
-	GdkPixbuf *icon;
+	GdkPixbuf *icon = NULL;
+
 	const char *authors[] = 
 	{
 		"Jörgen Scheibengruber <mfcn@gmx.de>", 
 		"Dennis Cranston <dennis_cranston@yahoo.com> - HIGifing",
 		NULL
 	};
-	NetspeedApplet *applet = (NetspeedApplet*)data;
-	
+
 	/* Feel free to put your names here translators :-) */
 	char *translators = _("TRANSLATORS");
 
-	if (applet->about)
-	{
-		gtk_window_present(GTK_WINDOW(applet->about));
-		return;
-	}
-	icon = gdk_pixbuf_new_from_xpm_data(ICON_APPLET);
+	icon = gdk_pixbuf_new_from_xpm_data (ICON_APPLET);
 	
-	applet->about = GTK_DIALOG(gnome_about_new (_("Netspeed"), 
-				VERSION, "Copyright 2002 - 2003 Jörgen Scheibengruber",
-				_("A little applet that displays some information on the traffic on the specified networkdevice"),
-				(const char **) authors, NULL, strcmp("TRANSLATORS", translators) ? translators : NULL, 
-				icon));
- 
-	gdk_pixbuf_unref(icon);
-	g_object_add_weak_pointer(G_OBJECT(applet->about), (gpointer*)&applet->about);
-	gtk_widget_show(GTK_WIDGET(applet->about));
+	gtk_show_about_dialog (NULL, 
+			       "name", _("Netspeed"), 
+			       "version", VERSION, 
+			       "copyright", "Copyright 2002 - 2003 Jörgen Scheibengruber",
+			       "comments", _("A little applet that displays some information on the traffic on the specified network device"),
+			       "authors", authors, 
+			       "documenters", NULL, 
+			       "translator-credits", strcmp ("TRANSLATORS", translators) ? translators : NULL, 
+			       "logo", icon,
+			       NULL);
+	if (icon != NULL)
+		gdk_pixbuf_unref (icon);
 }
 
 
@@ -762,7 +761,6 @@ settings_cb(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 	GtkWidget *label_font_size_hbox2;
 	GtkWidget *label_font_size_label;
 	GtkWidget *label_font_size_spinbutton;
-	GtkObject *label_font_size_spinbutton_adj;
 	GtkWidget *indent_label;
 	GtkWidget *points_label;
 	GtkWidget *millisecond_label;
@@ -1018,7 +1016,7 @@ showinfo_cb(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
 	NetspeedApplet *applet = (NetspeedApplet*)data;
 	GtkWidget *box, *hbox;
-	GtkWidget *frame, *table, *da_frame;
+	GtkWidget *table, *da_frame;
 	GtkWidget *ip_label, *netmask_label;
 	GtkWidget *hwaddr_label, *ptpip_label;
 	GtkWidget *ip_text, *netmask_text;
@@ -1027,7 +1025,6 @@ showinfo_cb(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 	GtkWidget *incolor_sel, *incolor_label;
 	GtkWidget *outcolor_sel, *outcolor_label;
 	char *title;
-	int response;
 	
 	g_assert(applet);
 	
@@ -1295,7 +1292,6 @@ netspeed_applet_factory(PanelApplet *applet_widget, const gchar *iid, gpointer d
 	NetspeedApplet *applet;
 	int i;
 	char* menu_string;
-	char* first_device;
 	GdkPixbuf *icon;
 	GList *iconlist = NULL;
 	
